#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hiedb
version:              0.4.3.0
visibility:           public
id:                   hiedb-0.4.3.0-32LDehR2hktAfCUHLkEXQ9
key:                  hiedb-0.4.3.0-32LDehR2hktAfCUHLkEXQ9
license:              BSD-3-Clause
copyright:            Zubin Duggal
maintainer:           zubin.duggal@gmail.com
author:               Zubin Duggal
synopsis:             Generates a references DB from .hie files
description:
    Tool and library to index and query a collection of `.hie` files

category:             Development
abi:                  6a5debe576cab8ebd87279346aba7802
exposed:              True
exposed-modules:
    HieDb HieDb.Compat HieDb.Create HieDb.Dump HieDb.Html HieDb.Query
    HieDb.Run HieDb.Types HieDb.Utils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hiedb-0.4.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hiedb-0.4.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hiedb-0.4.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hiedb
hs-libraries:         HShiedb-0.4.3.0-32LDehR2hktAfCUHLkEXQ9
depends:
    algebraic-graphs-0.8-A4EVnESAngK9oQQqL6tfeI
    ansi-terminal-1.1-B9wXUZLJN9hAlKDPl1kvvR array-0.5.6.0
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.8.5 extra-1.7.16-7Us6XiRrmi4JVcvk4FvIio
    filepath-1.4.300.1 ghc-9.6.6
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    lucid-2.11.20250303-HuGSdm9FF8kg9K2pwcD0p mtl-2.3.1
    optparse-applicative-0.18.1.0-vPoWCngm2S3ZG61FOtDDl
    sqlite-simple-0.4.19.0-8znbitD9bMlC3MM3Kyh9L3
    terminal-size-0.3.4-RfZxi4foNwK9w669pzI7h text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hiedb/html/hiedb.haddock
haddock-html:         /usr/share/doc/haskell-hiedb/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

